<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>AppMgmtDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1303"/>
        <source>Manage External Applications</source>
        <translation>Gestion des applications externes</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1315"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1317"/>
        <source>Application path and arguments</source>
        <translation>Emplacement et options de l&apos;application</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1323"/>
        <source>Choose</source>
        <translation>Choisir</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1327"/>
        <source>Add manually</source>
        <translation>Ajouter manuellement</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1331"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1338"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1378"/>
        <source>Choose Application</source>
        <translation>Choisir l&apos;application</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1390"/>
        <source>New Application</source>
        <translation>Nouvelle Application</translation>
    </message>
</context>
<context>
    <name>ColorsDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1008"/>
        <source>Colors</source>
        <translation>Couleurs</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1014"/>
        <source>Reset</source>
        <translation>Réinitialiser</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1019"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1027"/>
        <source>Hue</source>
        <translation>Teinte</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1028"/>
        <source>Saturation</source>
        <translation>Saturation</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1029"/>
        <source>Lightness</source>
        <translation>Clarté</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="vanished">Canaux</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="vanished">Activer</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1038"/>
        <source>Colorize</source>
        <translation>Coloriser</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1042"/>
        <location filename="../dialogs.cpp" line="1046"/>
        <location filename="../dialogs.cpp" line="1050"/>
        <source>Negative</source>
        <translation>Négatif</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1069"/>
        <location filename="../dialogs.cpp" line="1135"/>
        <source>Red</source>
        <translation>Rouge</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1074"/>
        <location filename="../dialogs.cpp" line="1143"/>
        <source>Green</source>
        <translation>Vert</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1079"/>
        <location filename="../dialogs.cpp" line="1151"/>
        <source>Blue</source>
        <translation>Bleu</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1096"/>
        <source>Hue and Saturation</source>
        <translation>Teinte et Saturation</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1102"/>
        <source>Affected Channels</source>
        <translation>Canaux affectés</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1106"/>
        <source>Brightness</source>
        <translation>Luminosité</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1107"/>
        <source>Contrast</source>
        <translation>Contraste</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1131"/>
        <source>Brightness and Contrast</source>
        <translation>Luminosité et Contraste</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1171"/>
        <source>Color Balance</source>
        <translation>Balance des couleurs</translation>
    </message>
</context>
<context>
    <name>CopyMoveToDialog</name>
    <message>
        <source>Copy or Move Images to...</source>
        <translation type="vanished">Copier ou Déplacer les images vers...</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="vanished">Ajouter</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1407"/>
        <source>Move to...</source>
        <translation>Déplacer vers...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1410"/>
        <source>Copy to...</source>
        <translation>Copier vers...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1438"/>
        <source>Browse...</source>
        <translation>Parcourir...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1440"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1447"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1452"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1463"/>
        <location filename="../dialogs.cpp" line="1489"/>
        <source>Destination:</source>
        <translation>Destination :</translation>
    </message>
    <message>
        <source>Destination: </source>
        <translation type="vanished">Destination : </translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Fermer</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Copier</translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="vanished">Déplacer</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1529"/>
        <source>Choose Folder</source>
        <translation>Sélectionner le dossier</translation>
    </message>
</context>
<context>
    <name>CpMvDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="28"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="113"/>
        <location filename="../dialogs.cpp" line="141"/>
        <source>Copying &quot;%1&quot; to &quot;%2&quot;.</source>
        <translation>Copie de &quot;%1&quot; vers &quot;%2&quot;.</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="113"/>
        <location filename="../dialogs.cpp" line="142"/>
        <source>Moving &quot;%1&quot; to &quot;%2&quot;.</source>
        <translation>Déplacement de &quot;%1&quot; vers &quot;%2&quot;.</translation>
    </message>
    <message>
        <source>Copying </source>
        <translation type="vanished">Copie de </translation>
    </message>
    <message>
        <source>Moving </source>
        <translation type="vanished">Déplacement de </translation>
    </message>
    <message>
        <source> to </source>
        <translation type="vanished"> vers </translation>
    </message>
</context>
<context>
    <name>CropDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="688"/>
        <source>Cropping</source>
        <translation>Rogner</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="696"/>
        <source>Reset</source>
        <translation>Réinitialiser</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="699"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="737"/>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="735"/>
        <source>Left</source>
        <translation>Gauche</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="736"/>
        <source>Right</source>
        <translation>Droite</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="738"/>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
</context>
<context>
    <name>ImageTags</name>
    <message>
        <location filename="../tags.cpp" line="59"/>
        <source>Tag</source>
        <translation>Taguer</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="63"/>
        <source>Untag</source>
        <translation>Détaguer</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="73"/>
        <source>Clear Filters</source>
        <translation>Effacer les filtres</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="66"/>
        <source>New Tag</source>
        <translation>Nouveau tag</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="36"/>
        <source>Image Tags</source>
        <translation>Tag de l&apos;image</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="37"/>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="70"/>
        <source>Remove Tag</source>
        <translation>Supprimer le tag</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="77"/>
        <source>Negate</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="179"/>
        <location filename="../tags.cpp" line="482"/>
        <location filename="../tags.cpp" line="491"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="179"/>
        <source>Failed to save tags to </source>
        <translation>Échec de la sauvegarde des tags vers </translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="381"/>
        <source>Tagging </source>
        <translation>Tague </translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="384"/>
        <source>Untagging </source>
        <translation>Détague </translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="473"/>
        <source>Add a new tag</source>
        <translation>Ajouter un nouveau tag</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="474"/>
        <source>Enter new tag name</source>
        <translation>Entrer le nouveau nom du tag</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="482"/>
        <source>No name entered</source>
        <translation>Aucun nom saisi</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="491"/>
        <source>Tag </source>
        <translation>Le tag </translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="491"/>
        <source> already exists</source>
        <translation> existe déjà</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="508"/>
        <source>Remove selected tags(s)?</source>
        <translation>Supprimer le(s) tag(s) sélectionné(s) ?</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="509"/>
        <source>Remove tag</source>
        <translation>Supprimer le tag</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="514"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="515"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <location filename="../imageview.cpp" line="626"/>
        <source>Clipboard</source>
        <translation>Presse-papier</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="780"/>
        <source>Selection size: </source>
        <translation>Sélection de la taille : </translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="828"/>
        <source>No selection</source>
        <translation>Aucune sélection</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="828"/>
        <source>Hold down the Ctrl key and select a region using the mouse.</source>
        <translation>Maintenez la touche Ctrl enfoncée et sélectionnez une région à l&apos;aide de la souris.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="975"/>
        <location filename="../imageview.cpp" line="1021"/>
        <source>Failed to save image.</source>
        <translation>Échec de la sauvegarde de l&apos;image.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="988"/>
        <source>Failed to save Exif metadata.</source>
        <translation>Échec de la sauvegarde des méta-données Exif.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="993"/>
        <location filename="../imageview.cpp" line="1034"/>
        <source>Image saved.</source>
        <translation>Image enregistrée.</translation>
    </message>
    <message>
        <source>Hold down the Ctrl key and select a region using the mouse</source>
        <translation type="vanished">Maintenez la touche Ctrl enfoncée et sélectionnez une région à l&apos;aide de la souris</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="958"/>
        <source>Saving...</source>
        <translation>Sauvegarde en cours...</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="975"/>
        <location filename="../imageview.cpp" line="988"/>
        <location filename="../imageview.cpp" line="1021"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <source>Failed to save image</source>
        <translation type="vanished">Échec de la sauvegarde de l&apos;image</translation>
    </message>
    <message>
        <source>Failed to save Exif metadata</source>
        <translation type="vanished">Échec de la sauvegarde des méta-données Exif</translation>
    </message>
    <message>
        <source>Image saved</source>
        <translation type="vanished">Image enregistrée</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="1005"/>
        <source>Save image as</source>
        <translation>Enregistrer l&apos;image sous</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="1007"/>
        <source>Images</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Image Files</source>
        <translation type="vanished">Fichiers Image</translation>
    </message>
</context>
<context>
    <name>InfoView</name>
    <message>
        <location filename="../infoview.cpp" line="40"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
</context>
<context>
    <name>KeyGrabLineEdit</name>
    <message>
        <source>Set shortcut</source>
        <translation type="vanished">Définir un raccourci</translation>
    </message>
    <message>
        <source> is reserved for shortcuts to external applications</source>
        <translation type="vanished"> est réservé pour les raccourcis d&apos;applications externes</translation>
    </message>
    <message>
        <source> is already assigned to &quot;</source>
        <translation type="vanished"> est déjà attribué à &quot;</translation>
    </message>
    <message>
        <source>&quot; action</source>
        <translation type="vanished">&quot; action</translation>
    </message>
</context>
<context>
    <name>Phototonic</name>
    <message>
        <location filename="../mainwindow.cpp" line="2232"/>
        <source>Docks and Toolbars</source>
        <translation>Docks et Barres d&apos;outils</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Image Info</source>
        <translation>Information Image</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="201"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>Transform</source>
        <translation>Transformer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <source>Mirroring</source>
        <translation>Effet miroir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Top</source>
        <translation>Haut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Bottom</source>
        <translation>Bas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Close Image</source>
        <translation>Fermer l&apos;image</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Full Screen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Enlarge Thumbnails</source>
        <translation>Agrandir les vignettes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Shrink Thumbnails</source>
        <translation>Rétrécir les vignettes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Copy or Move to...</source>
        <translation type="vanished">Copier ou Déplacer vers...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Save As</source>
        <translation>Enregistrer sous</translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation type="vanished">Copier l&apos;image</translation>
    </message>
    <message>
        <source>Paste Image</source>
        <translation type="vanished">Coller l&apos;image</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <location filename="../mainwindow.cpp" line="3151"/>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>Select All</source>
        <translation>Tout sélectionner</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>About</source>
        <translation>À propos de</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Time</source>
        <translation>Date</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Reverse</source>
        <translation>Inverser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Show Hidden Files</source>
        <translation>Afficher les fichiers cachés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>Show Labels</source>
        <translation>Afficher les labels</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Small Icons</source>
        <translation>Petites icônes</translation>
    </message>
    <message>
        <source>Hide Docks Title Bar</source>
        <translation type="vanished">Masquer la barre de titre des Docks</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>Show Toolbar</source>
        <translation>Afficher la barre d&apos;outils</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Classic Thumbs</source>
        <translation>Classique</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Compact</source>
        <translation>Compact</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Squarish</source>
        <translation>Carré</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Reload</source>
        <translation>Recharger</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Include Sub-folders</source>
        <translation>Inclure les sous-dossiers</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Paste Here</source>
        <translation>Coller ici</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="465"/>
        <source>New Folder</source>
        <translation>Nouveau dossier</translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="obsolete">Gérer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>Back</source>
        <translation>Retour</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="476"/>
        <source>Forward</source>
        <translation>Avancer</translation>
    </message>
    <message>
        <source>Up</source>
        <translation type="vanished">Monter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Home</source>
        <translation>Début</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <location filename="../mainwindow.cpp" line="2717"/>
        <source>Slide Show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Previous</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="507"/>
        <source>First</source>
        <translation>Premier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Last</source>
        <translation>Dernier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Random</source>
        <translation>Aléatoire</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Show Clipboard</source>
        <translation type="vanished">Afficher le presse-papier</translation>
    </message>
    <message>
        <source>Open With</source>
        <translation type="vanished">Ouvrir avec</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="535"/>
        <source>Manage External Applications</source>
        <translation>Gérer les applications externes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Add Bookmark</source>
        <translation>Ajouter aux signets</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Remove Bookmark</source>
        <translation>Retirer des signets</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Zoom Out</source>
        <translation>Zoom arrière</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Zoom In</source>
        <translation>Zoom avant</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>Reset Zoom</source>
        <translation>Réinitialiser le zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="563"/>
        <location filename="../mainwindow.cpp" line="1424"/>
        <source>Original Size</source>
        <translation>Taille d&apos;origine</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>Keep Zoom</source>
        <translation>Conserver le zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>Rotate 90 degree CCW</source>
        <translation>Rotation de 90° sens anti-horaire</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <source>Rotate 90 degree CW</source>
        <translation>Rotation de 90° sens horaire</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Flip Horizontally</source>
        <translation>Miroir horizontal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <source>Flip Vertically</source>
        <translation>Miroir vertical</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>Cropping</source>
        <translation>Rogner</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Crop to Selection</source>
        <translation>Rogner jusqu&apos;à la sélection</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="602"/>
        <source>Scale Image</source>
        <translation>Redimensionner l&apos;image</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Rotate 1 degree CCW</source>
        <translation>Rotation de 1° sens anti-horaire</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Rotate 1 degree CW</source>
        <translation>Rotation de 1° sens horaire</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="615"/>
        <source>Colors</source>
        <translation>Couleurs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="620"/>
        <source>Find Duplicate Images</source>
        <translation>Rechercher des doublons</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Disable</source>
        <translation>Désactiver</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="628"/>
        <source>Dual</source>
        <translation>Double</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Triple</source>
        <translation>Triple</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Dual Vertical</source>
        <translation>Double vertical</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Quad</source>
        <translation>Quadruple</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1384"/>
        <source>Minimum zoom</source>
        <translation>Zoom minimum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1402"/>
        <source>Maximum zoom</source>
        <translation>Zoom maximum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1459"/>
        <location filename="../mainwindow.cpp" line="1468"/>
        <location filename="../mainwindow.cpp" line="1525"/>
        <location filename="../mainwindow.cpp" line="1534"/>
        <source>Rotation %1°</source>
        <translation>Rotation de %1°</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2703"/>
        <source>Failed to open file &quot;%1&quot;, file not found.</source>
        <translation>Échec de l&apos;ouverture du fichier &quot;%1&quot;, fichier introuvable.</translation>
    </message>
    <message>
        <source>Failed to open file &quot;%1&quot;: file not found.</source>
        <translation type="vanished">Échec de l&apos;ouverture du fichier &quot;%1&quot;: fichier introuvable.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2983"/>
        <source>Can not move or copy images to this folder.</source>
        <translation>Impossible de déplacer ou couper les images dans ce dossier.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2989"/>
        <source>Destination folder is same as source.</source>
        <translation>Le dossier de destination et le dossier source sont identiques.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2997"/>
        <source>Move &quot;%1&quot; to &quot;%2&quot;?</source>
        <translation>Déplacement de &quot;%1&quot; vers &quot;%2&quot; ?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3006"/>
        <source>Failed to move folder.</source>
        <translation>Échec du déplacement du dossier.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3108"/>
        <source>Failed to open folder:</source>
        <translation>Échec de l&apos;ouverture du dossier :</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3140"/>
        <source>Duplicate images in %1</source>
        <translation>Images dupliquées dans %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3164"/>
        <location filename="../mainwindow.cpp" line="3338"/>
        <source>Invalid name entered.</source>
        <translation>Nom saisi invalide.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3175"/>
        <source>Failed to rename folder.</source>
        <translation>Échec du renommage du dossier.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3222"/>
        <source>Enter a new name for &quot;%1&quot;:</source>
        <translation>Saisir un nouveau nom pour &quot;%1&quot; :</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3235"/>
        <source>No name entered.</source>
        <translation>Aucun nom saisi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3265"/>
        <source>Failed to rename image.</source>
        <translation>Échec du renommage de l&apos;image.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3281"/>
        <source>Permanently delete &quot;%1&quot; and all of its contents?</source>
        <translation>Supprimer définitivement &quot;%1&quot; et tout ce qu&apos;il contient ?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3304"/>
        <source>Failed to delete folder.</source>
        <translation>Échec de la suppression du dossier.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3308"/>
        <source>Removed &quot;%1&quot;</source>
        <translation>Supprimé &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3349"/>
        <source>Failed to create new folder.</source>
        <translation>Échec de la création du nouveau dossier.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3354"/>
        <source>Created &quot;%1&quot;</source>
        <translation>Créé &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3395"/>
        <source>Cannot perform action with temporary image.</source>
        <translation>Impossible d&apos;exécuter cette action avec l&apos;image temporaire.</translation>
    </message>
    <message>
        <source>Keep Transformations</source>
        <translation type="vanished">Conserver les transformations</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="654"/>
        <source>Move Left</source>
        <translation>Déplacer vers la gauche</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="657"/>
        <source>Move Right</source>
        <translation>Déplacer vers la droite</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>Move Up</source>
        <translation>Déplacer vers le haut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>Move Down</source>
        <translation>Déplacer vers le bas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Invert Selection</source>
        <translation>Inverser la sélection</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <source>Filter by Name</source>
        <translation>Filtrer par nom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Set Path</source>
        <translation>Définir le chemin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="681"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>&amp;Edit</source>
        <translation>&amp;Édition</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="705"/>
        <source>&amp;Go</source>
        <translation>A&amp;ller à</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>&amp;View</source>
        <translation>Afficha&amp;ge</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="720"/>
        <source>Sort By</source>
        <translation>Trier par</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>&amp;Tools</source>
        <translation>&amp;Outils</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="747"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="771"/>
        <source>Edit</source>
        <translation>Édition</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>Navigation</source>
        <translation>Navigation</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <location filename="../mainwindow.cpp" line="253"/>
        <location filename="../mainwindow.cpp" line="801"/>
        <source>View</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="808"/>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="871"/>
        <source>Initializing...</source>
        <translation>Initialisation...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>File System</source>
        <translation>Système de fichiers</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1044"/>
        <source>&lt;p&gt;Image viewer and organizer&lt;/p&gt;</source>
        <translation>&lt;p&gt;Visionneuse et organisatrice d&apos;image&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Git release</source>
        <translation type="vanished">&lt;p&gt;Révision Git</translation>
    </message>
    <message>
        <source>Built with Qt </source>
        <translation type="vanished">Compilé avec Qt </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1046"/>
        <source>Home page</source>
        <translation>Page d&apos;accueil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1047"/>
        <source>Bug reports</source>
        <translation>Rapports de bogue</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1104"/>
        <source>Failed to start external application.</source>
        <translation>Échec du lancement de l&apos;application externe.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1128"/>
        <source>Invalid selection.</source>
        <translation>Sélection invalide.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1330"/>
        <source>Failed to copy or move image.</source>
        <translation>Échec de la copie ou du déplacement de l&apos;image.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1390"/>
        <location filename="../mainwindow.cpp" line="1408"/>
        <source>Zoom %1%</source>
        <translation>Zoom à %1%</translation>
    </message>
    <message>
        <source>Rotation %1u00B0</source>
        <translation type="vanished">Rotation de %1u00B0</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>Copied</source>
        <translation>Copié</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>Moved</source>
        <translation>Déplacer</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1676"/>
        <location filename="../mainwindow.cpp" line="1870"/>
        <location filename="../mainwindow.cpp" line="3028"/>
        <source>%n image(s)</source>
        <translation>
            <numerusform>%n image</numerusform>
            <numerusform>%n images</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1739"/>
        <source>Permanently delete</source>
        <translation>Supprimer définitivement</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1842"/>
        <source>Failed to delete image.</source>
        <translation>Échec de la suppression de l&apos;image.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1870"/>
        <source>Deleted</source>
        <translation>Supprimé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1902"/>
        <source>Invalid Path:</source>
        <translation>Emplacement invalide :</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2216"/>
        <source>Viewer</source>
        <translation>Visionneuse</translation>
    </message>
    <message>
        <source>Contributors:&lt;br&gt;</source>
        <translation type="obsolete">Contributeurs:&lt;br&gt;</translation>
    </message>
    <message>
        <source>Contributors / Translations:&lt;br&gt;</source>
        <translation type="obsolete">Contributeurs / Traductions:&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3208"/>
        <source>Invalid selection</source>
        <translation>Sélection invalide</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1104"/>
        <location filename="../mainwindow.cpp" line="1330"/>
        <location filename="../mainwindow.cpp" line="1638"/>
        <location filename="../mainwindow.cpp" line="1651"/>
        <location filename="../mainwindow.cpp" line="1761"/>
        <location filename="../mainwindow.cpp" line="1842"/>
        <location filename="../mainwindow.cpp" line="1902"/>
        <location filename="../mainwindow.cpp" line="2703"/>
        <location filename="../mainwindow.cpp" line="2983"/>
        <location filename="../mainwindow.cpp" line="2989"/>
        <location filename="../mainwindow.cpp" line="3006"/>
        <location filename="../mainwindow.cpp" line="3108"/>
        <location filename="../mainwindow.cpp" line="3164"/>
        <location filename="../mainwindow.cpp" line="3175"/>
        <location filename="../mainwindow.cpp" line="3235"/>
        <location filename="../mainwindow.cpp" line="3265"/>
        <location filename="../mainwindow.cpp" line="3304"/>
        <location filename="../mainwindow.cpp" line="3338"/>
        <location filename="../mainwindow.cpp" line="3349"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Copy to...</source>
        <translation>Copier vers...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>Move to...</source>
        <translation>Déplacer vers...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>Copy Image Data</source>
        <translation>Copier le contenu de l&apos;image</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>Paste Image Data</source>
        <translation>Coller le contenu de l&apos;image</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>Hide Dock Title Bars</source>
        <translation>Masquer les barres de titre du dock</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="482"/>
        <source>Go Up</source>
        <translation>Monter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Load Clipboard</source>
        <translation>Charger le presse-papier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>Open With...</source>
        <translation>Ouvrir avec...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>Lock Transformations</source>
        <translation>Verrouiller les transformations</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>Image</source>
        <translation>Image</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="922"/>
        <source>Bookmarks</source>
        <translation>Signets</translation>
    </message>
    <message>
        <source>Failed to start external application</source>
        <translation type="vanished">Échec du lancement de l&apos;application externe</translation>
    </message>
    <message>
        <source>Failed to copy or move image</source>
        <translation type="vanished">Échec de la copie ou du déplacement de l&apos;image</translation>
    </message>
    <message>
        <source>Zoom Out to </source>
        <translation type="vanished">Zoom arrière sur </translation>
    </message>
    <message>
        <source>Zoom In to </source>
        <translation type="vanished">Zoom avant sur </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1416"/>
        <source>Zoom Reset</source>
        <translation>Réinitialisation du zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1431"/>
        <source>Zoom Locked</source>
        <translation>Zoom verrouillé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1433"/>
        <source>Zoom Unlocked</source>
        <translation>Zoom déverrouillé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1442"/>
        <source>Transformations Locked</source>
        <translation>Transformations verrouillées</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1447"/>
        <source>Transformations Unlocked</source>
        <translation>Transformations déverrouillées</translation>
    </message>
    <message>
        <source>Rotation </source>
        <translation type="vanished">Rotation de </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1475"/>
        <source>Flipped Vertically</source>
        <translation>Retourné à la verticale</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1475"/>
        <source>Unflipped Vertically</source>
        <translation>Rétabli à la verticale</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1482"/>
        <source>Flipped Horizontally</source>
        <translation>Retourné à l&apos;horizontale</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1482"/>
        <source>Unflipped Horizontally</source>
        <translation>Rétabli à l&apos;horizontale</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1578"/>
        <source>Mirroring Disabled</source>
        <translation>Effet miroir désactivé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1585"/>
        <source>Mirroring: Dual</source>
        <translation>Effet miroir : double</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1592"/>
        <source>Mirroring: Triple</source>
        <translation>Effet miroir : triple</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1599"/>
        <source>Mirroring: Dual Vertical</source>
        <translation>Effet miroir : double vertical</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1606"/>
        <source>Mirroring: Quad</source>
        <translation>Effet miroir : quadruple</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1638"/>
        <source>Can not copy or move to </source>
        <translation>Impossible de copier ou déplacer vers </translation>
    </message>
    <message>
        <source>Can not cut and paste in the same folder</source>
        <translation type="vanished">Impossible de couper et coller dans le même dossier</translation>
    </message>
    <message>
        <source>Copied </source>
        <translation type="vanished">Copié </translation>
    </message>
    <message>
        <source>Moved </source>
        <translation type="vanished">Déplacé </translation>
    </message>
    <message>
        <source> images</source>
        <translation type="vanished"> images</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1740"/>
        <source>Delete image</source>
        <translation>Supprimer l&apos;image</translation>
    </message>
    <message>
        <source>Permanently delete </source>
        <translation type="vanished">Supprimer définitivement </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1761"/>
        <source>Failed to delete image</source>
        <translation>Échec de la suppression de l&apos;image</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1507"/>
        <location filename="../mainwindow.cpp" line="1798"/>
        <source>No selection</source>
        <translation>Aucune sélection</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1807"/>
        <source>Delete images</source>
        <translation>Supprimer les images</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1806"/>
        <source>Permanently delete selected images?</source>
        <translation>Supprimer définitivement les images sélectionnées ?</translation>
    </message>
    <message>
        <source>Contributors / Code:</source>
        <translation type="vanished">Contributeurs / Code :</translation>
    </message>
    <message>
        <source>Contributors / Translations:</source>
        <translation type="vanished">Contributeurs / Traductions :</translation>
    </message>
    <message>
        <source>Zoom </source>
        <translation type="vanished">Zoom à </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1651"/>
        <source>Can not copy or move to the same folder</source>
        <translation>Impossible de copier ou déplacer dans le même dossier</translation>
    </message>
    <message>
        <source> image(s)</source>
        <translation type="vanished"> image(s)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1744"/>
        <location filename="../mainwindow.cpp" line="1811"/>
        <location filename="../mainwindow.cpp" line="3289"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1745"/>
        <location filename="../mainwindow.cpp" line="1812"/>
        <location filename="../mainwindow.cpp" line="3290"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1758"/>
        <source>Deleted </source>
        <translation>Supprimé</translation>
    </message>
    <message>
        <source>Invalid Path: </source>
        <translation type="vanished">Emplacement invalide : </translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="obsolete">Prévisualisation</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2554"/>
        <source>No images</source>
        <translation>Aucunes images</translation>
    </message>
    <message>
        <source>Failed to open file </source>
        <translation type="vanished">Échec de l&apos;ouverture du fichier </translation>
    </message>
    <message>
        <source>, file not found</source>
        <translation type="vanished">, fichier introuvable</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2718"/>
        <source>Slide show stopped</source>
        <translation>Diaporama stoppé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2745"/>
        <source>Stop Slide Show</source>
        <translation>Arrêter le diaporama</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2746"/>
        <source>Slide show started</source>
        <translation>Diaporama démarré</translation>
    </message>
    <message>
        <source>Can not move or copy images to this folder</source>
        <translation type="vanished">Impossible de déplacer ou couper les images dans ce dossier</translation>
    </message>
    <message>
        <source>Destination folder is same as source</source>
        <translation type="vanished">Le dossier de destination et le dossier source sont identiques</translation>
    </message>
    <message>
        <source>Move </source>
        <translation type="vanished">Déplacer </translation>
    </message>
    <message>
        <source> to </source>
        <translation type="vanished"> vers </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2998"/>
        <source>Move folder</source>
        <translation>Déplacer le dossier</translation>
    </message>
    <message>
        <source>Failed to move folder</source>
        <translation type="vanished">Échec du déplacement du dossier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3008"/>
        <source>Folder moved</source>
        <translation>Dossier déplacé</translation>
    </message>
    <message>
        <source>Failed to open folder: </source>
        <translation type="vanished">Échec de l&apos;ouverture du dossier : </translation>
    </message>
    <message>
        <source>Rename </source>
        <translation type="vanished">Renommer </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3153"/>
        <source>New name:</source>
        <translation>Nouveau nom :</translation>
    </message>
    <message>
        <source>Invalid name entered</source>
        <translation type="vanished">Nom saisi invalide</translation>
    </message>
    <message>
        <source>Failed to rename folder</source>
        <translation type="vanished">Échec du renommage du dossier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3220"/>
        <source>Rename Image</source>
        <translation>Renommer l&apos;image</translation>
    </message>
    <message>
        <source>Enter a new name for </source>
        <translation type="vanished">Saisir un nouveau nom pour </translation>
    </message>
    <message>
        <source>No name entered</source>
        <translation type="vanished">Aucun nom saisi</translation>
    </message>
    <message>
        <source>Failed to rename image</source>
        <translation type="vanished">Échec du renommage de l&apos;image</translation>
    </message>
    <message>
        <source> and all of its contents?</source>
        <translation type="vanished"> et tout ce qu&apos;il contient ?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3285"/>
        <source>Delete folder</source>
        <translation>Supprimer le dossier</translation>
    </message>
    <message>
        <source>Failed to delete folder</source>
        <translation type="vanished">Échec de la suppression du dossier</translation>
    </message>
    <message>
        <source>Removed </source>
        <translation type="vanished">Supprimé </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3326"/>
        <source>New Sub folder</source>
        <translation>Nouveau sous-dossier</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3327"/>
        <source>New folder name:</source>
        <translation>Nom du nouveau dossier :</translation>
    </message>
    <message>
        <source>Failed to create new folder</source>
        <translation type="vanished">Échec de la création du nouveau dossier</translation>
    </message>
    <message>
        <source>Created </source>
        <translation type="vanished">Créé </translation>
    </message>
    <message>
        <source>Executing file manager...</source>
        <translation type="obsolete">Exécution du gestionnaire de fichiers...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3395"/>
        <source>Warning</source>
        <translation>Avertissement</translation>
    </message>
    <message>
        <source>Cannot perform action with temporary image</source>
        <translation type="vanished">Impossible d&apos;exécuter cette action avec l&apos;image temporaire</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1555"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Usage: phototonic [FILE or DIRECTORY]...</source>
        <translation type="vanished">Utilisation : phototonic [FICHIER ou REPERTOIRE]...</translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="813"/>
        <source>Scale Image</source>
        <translation>Redimensionnement de l&apos;image</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="825"/>
        <source>Scale</source>
        <translation>Redimensionner</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="829"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="845"/>
        <source>Original size:</source>
        <translation>Taille d&apos;origine :</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="848"/>
        <source>Width:</source>
        <translation>Largeur :</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="849"/>
        <source>Height:</source>
        <translation>Hauteur :</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="850"/>
        <source>Units:</source>
        <translation>Unités :</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="852"/>
        <source>New size:</source>
        <translation>Nouvelle taille :</translation>
    </message>
    <message>
        <source>Original size: </source>
        <translation type="vanished">Taille d&apos;origine : </translation>
    </message>
    <message>
        <source>Width: </source>
        <translation type="vanished">Largeur : </translation>
    </message>
    <message>
        <source>Height: </source>
        <translation type="vanished">Hauteur : </translation>
    </message>
    <message>
        <source>Units: </source>
        <translation type="vanished">Unités : </translation>
    </message>
    <message>
        <source>New size: </source>
        <translation type="vanished">Nouvelle taille : </translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="855"/>
        <source>Pixels</source>
        <translation>Pixels</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="857"/>
        <source>Percent</source>
        <translation>Pourcent</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="862"/>
        <source>Lock aspect ratio</source>
        <translation>Vérrouiller le rapport hauteur/largeur</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="270"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="275"/>
        <source>Fit Large Images</source>
        <translation>Adaptation des grandes images</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="276"/>
        <location filename="../dialogs.cpp" line="293"/>
        <source>Disable</source>
        <translation>Désactiver</translation>
    </message>
    <message>
        <source>By width and height</source>
        <translation type="vanished">Par la largeur et la hauteur</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="278"/>
        <location filename="../dialogs.cpp" line="295"/>
        <source>By width</source>
        <translation>Par la largeur</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="279"/>
        <location filename="../dialogs.cpp" line="296"/>
        <source>By height</source>
        <translation>Par la hauteur</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <location filename="../dialogs.cpp" line="297"/>
        <source>Stretch disproportionately</source>
        <translation>Étirer de manière disproportionnée</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Fit Small Images</source>
        <translation>Adaptation des petites images</translation>
    </message>
    <message>
        <source>Background color: </source>
        <translation type="vanished">Couleur de fond : </translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="323"/>
        <source>Exit instead of closing, when image is loaded from command line</source>
        <translation>Quitter au lieu de fermer, quand l&apos;image est chargée depuis la ligne de commande</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="327"/>
        <source>Wrap image list when reaching last or first image</source>
        <translation>Enrouler la liste d&apos;image en arrivant à la dernière ou à la première image</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="331"/>
        <source>Default quality when saving images:</source>
        <translation>Qualité par défaut lors de la sauvegarde des images :</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="309"/>
        <location filename="../dialogs.cpp" line="371"/>
        <source>Background color:</source>
        <translation>Couleur de fond :</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="277"/>
        <location filename="../dialogs.cpp" line="294"/>
        <source>By width or height</source>
        <translation>Par largeur ou hauteur</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="349"/>
        <source>Show image file name in viewer</source>
        <translation>Afficher le nom de l&apos;image dans la visionneuse</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="395"/>
        <source>Background image:</source>
        <translation>Image de fond :</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="414"/>
        <source>Add space between thumbnails:</source>
        <translation>Ajouter un espace entre les vignettes :</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="429"/>
        <source>Number of thumbnail pages to read ahead:</source>
        <translation>Nombre de pages de vignettes à parcourir :</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="452"/>
        <source>Delay between slides in seconds:</source>
        <translation>Temps entre les diapositives en secondes :</translation>
    </message>
    <message>
        <source>Default quality when saving images: </source>
        <translation type="vanished">Qualité par défaut lors de la sauvegarde des images : </translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="341"/>
        <source>Enable GIF animation</source>
        <translation>Activer l&apos;animation GIF</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="345"/>
        <source>Rotate image according to Exif orientation</source>
        <translation>Rotation de l&apos;image selon l&apos;orientation Exif</translation>
    </message>
    <message>
        <source>Show image file name in full screen mode</source>
        <translation type="vanished">Afficher le nom du fichier de l&apos;image en mode plein écran</translation>
    </message>
    <message>
        <source>        Label color: </source>
        <translation type="vanished">        Couleur du label : </translation>
    </message>
    <message>
        <source>Background image: </source>
        <translation type="vanished">Image de fond : </translation>
    </message>
    <message>
        <source>Add space between thumbnails: </source>
        <translation type="vanished">Ajouter un espace entre les vignettes : </translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="425"/>
        <source>Show original size of images smaller than the thumbnail size</source>
        <translation>Afficher la taille d&apos;origine des images qui sont plus petites que les vignettes</translation>
    </message>
    <message>
        <source>Number of thumbnail pages to read ahead: </source>
        <translation type="vanished">Nombre de pages de vignettes à parcourir : </translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="438"/>
        <source>Rotate thumbnails according to Exif orientation</source>
        <translation>Rotation des vignettes selon l&apos;orientation Exif</translation>
    </message>
    <message>
        <source>Delay between slides in seconds: </source>
        <translation type="vanished">Temps entre les diapositives en secondes : </translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="383"/>
        <source>Label color:</source>
        <translation>Couleur du label :</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="462"/>
        <source>Show random images</source>
        <translation>Afficher des images aléatoires</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="472"/>
        <source>Startup folder</source>
        <translation>Dossier de démarrage</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="474"/>
        <source>Default, or specified by command line argument</source>
        <translation>Par défaut, ou spécifié par l&apos;argument de la ligne de commande</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="475"/>
        <source>Remember last</source>
        <translation>Rappeler le dernier</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="476"/>
        <source>Specify:</source>
        <translation>Spécifier :</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="523"/>
        <source>Swap mouse left-click and middle-click actions</source>
        <translation>Permuter les actions des clic gauche et clic du milieu de la souris</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="527"/>
        <source>Delete confirmation</source>
        <translation>Supprimer la confirmation</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="531"/>
        <source>Keyboard Shortcuts</source>
        <translation>Raccourcis clavier</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="681"/>
        <source>Open File</source>
        <translation>Ouvrir un fichier</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="682"/>
        <source>Images</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Keyboard shortcuts</source>
        <translation type="obsolete">Raccourcis clavier</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="545"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="550"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="562"/>
        <source>Viewer</source>
        <translation>Visionneuse</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="566"/>
        <source>Thumbnails</source>
        <translation>Vignettes</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="570"/>
        <source>Slide Show</source>
        <translation>Diaporama</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="574"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="674"/>
        <source>Choose Startup Folder</source>
        <translation>Choisir le dossier de démarrage</translation>
    </message>
</context>
<context>
    <name>ShortcutsTable</name>
    <message>
        <location filename="../dialogs.cpp" line="170"/>
        <source>Action</source>
        <translation>Action</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="171"/>
        <source>Shortcut</source>
        <translation>Raccourci</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>Delete shortcut</source>
        <translation>Supprimer le raccourci</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="227"/>
        <location filename="../dialogs.cpp" line="239"/>
        <source>Set shortcut</source>
        <translation>Définir un raccourci</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="228"/>
        <source>&quot;%1&quot; is reserved for shortcuts to external applications.</source>
        <translation>&quot;%1&quot; est réservé pour les raccourcis d&apos;applications externes.</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="240"/>
        <source>&quot;%1&quot; is already assigned to &quot;%2&quot; action.</source>
        <translation>&quot;%1&quot; est déjà attribué à &quot;%2&quot; action.</translation>
    </message>
    <message>
        <source> is reserved for shortcuts to external applications</source>
        <translation type="obsolete"> est réservé pour les raccourcis d&apos;applications externes</translation>
    </message>
    <message>
        <source> is already assigned to &quot;</source>
        <translation type="obsolete"> est déjà attribué à &quot;</translation>
    </message>
    <message>
        <source>&quot; action</source>
        <translation type="obsolete">&quot; action</translation>
    </message>
</context>
<context>
    <name>ThumbView</name>
    <message>
        <source> images</source>
        <translation type="vanished"> images</translation>
    </message>
    <message>
        <source>Selected </source>
        <translation type="vanished">Sélection de </translation>
    </message>
    <message>
        <source> of </source>
        <translation type="vanished"> sur </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="247"/>
        <source>File name</source>
        <translation>Nom du fichier</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="251"/>
        <source>Location</source>
        <translation>Emplacement</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="264"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="268"/>
        <source>Resolution</source>
        <translation>Résolution</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="274"/>
        <source>Megapixel</source>
        <translation>Mégapixel</translation>
    </message>
    <message>
        <source>Selected %1 of %2</source>
        <translation type="vanished">Sélection de %1 sur %2</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="683"/>
        <source>Scanned %1, displaying %2 (%3 and %4)</source>
        <translation>Analyse de %1, affichage de %2 (%3 et %4)</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="686"/>
        <source>%n original(s)</source>
        <translation>
            <numerusform>%n original</numerusform>
            <numerusform>%n originaux</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="687"/>
        <source>%n duplicate(s)</source>
        <translation>
            <numerusform>%n doublon</numerusform>
            <numerusform>%n doublons</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="255"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="245"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="259"/>
        <source>Modified</source>
        <translation>Modifié</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="282"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="463"/>
        <location filename="../thumbview.cpp" line="684"/>
        <location filename="../thumbview.cpp" line="685"/>
        <source>%n image(s)</source>
        <translation>
            <numerusform>%n image</numerusform>
            <numerusform>%n images</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="297"/>
        <source>Selected %1 of%2</source>
        <translation>Sélection de %1 sur%2</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="299"/>
        <source> %n image(s)</source>
        <translation>
            <numerusform> %n image</numerusform>
            <numerusform> %n images</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="582"/>
        <source>Searching duplicate images...</source>
        <translation>Recherche de doublons...</translation>
    </message>
    <message>
        <source>Scanned </source>
        <translation type="vanished">Analyse de </translation>
    </message>
    <message numerus="yes">
        <source>%n images, displaying </source>
        <translation type="vanished">
            <numerusform>%n image, affichage de </numerusform>
            <numerusform>%n images, affichage de </numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n images (</source>
        <translation type="vanished">
            <numerusform>%n image pertinente (</numerusform>
            <numerusform>%n images pertinentes (</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n originals and </source>
        <translation type="obsolete">
            <numerusform>%n original et </numerusform>
            <numerusform>%n originaux et </numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n duplicates)</source>
        <translation type="vanished">
            <numerusform>%n doublon)</numerusform>
            <numerusform>%n doublons)</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="465"/>
        <source>No images</source>
        <translation>Aucunes images</translation>
    </message>
</context>
</TS>
